==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/tv.inc.php <==
<?php
/**
* TV Japanese lexicon topic
*
* @language ja
* @package modx
* @subpackage lexicon
* @author Nick http://smallworld.west-tokyo.com
* @author shimojo http://www.priqia.com/
* @author yamamoto http://kyms.jp
* @author honda http://kogus.org
*/
$_lang['has_access'] = 'アクセスしますか？';
$_lang['rank'] = 'ランク';
$_lang['rendering_options'] = 'レンダリングオプション';
$_lang['tv'] = 'テンプレート変数';
$_lang['tv_access_msg'] = 'このテンプレート変数が所属するリソースグループを選択して下さい。選択したグループへのアクセス権を持つユーザのみがこのテンプレート変数を修正することができます。 もしグループが選ばれていなければ、管理画面へのアクセス権を持つ全てのユーザがテンプレート変数を修正することができます。';
$_lang['tv_binding_msg'] = 'このフィールドは、＠コマンドを使用し、データソースバインディングをサポートしています。';
$_lang['tv_caption'] = '説明';
$_lang['tv_change_template_msg'] = 'このテンプレートを変更するとこのページのテンプレート変数を再読み込みします。保存されていない変更は失われます。<br /><br />本当にテンプレートを変更しますか？';
$_lang['tv_desc_caption'] = 'リソース編集時、テンプレート変数の横に表示されるテキスト。';
$_lang['tv_desc_category'] = 'このテンプレート変数が属するカテゴリー。';
$_lang['tv_desc_description'] = 'このテンプレート変数の簡単な説明。';
$_lang['tv_desc_name'] = 'テンプレート変数の名前。テンプレート変数は[[*テンプレート変数名]]という書式で利用できるようになります。';
$_lang['tv_description'] = '説明';
$_lang['tv_err_delete'] = 'テンプレート変数の削除中にエラーが発生しました。';
$_lang['tv_err_duplicate'] = 'テンプレート変数の複製中にエラーが発生しました。';
$_lang['tv_err_duplicate_templates'] = 'テンプレート変数のテンプレートを複製中にエラーが発生しました。';
$_lang['tv_err_duplicate_documents'] = 'テンプレート変数のドキュメントを複製中にエラーが発生しました。';
$_lang['tv_err_duplicate_documentgroups'] = 'テンプレート変数のドキュメントグループを複製中にエラーが発生しました。';
$_lang['tv_err_exists_name'] = '[[+name]]という名前のテンプレート変数がすでに存在します。';
$_lang['tv_err_invalid_name'] = 'テンプレート変数名に無効な文字列が使用されています。';
$_lang['tv_err_locked'] = 'テンプレート変数がロックされました。';
$_lang['tv_err_nf'] = 'テンプレート変数が見つかりませんでした。';
$_lang['tv_err_nfs'] = 'キー「[[+id]]」に関するテンプレート変数は見つかりません';
$_lang['tv_err_ns'] = 'テンプレート変数が指定されていません。';
$_lang['tv_err_reserved_name'] = 'テンプレート変数にはリソースフィールドと同じ名前を設定することはできません。';
$_lang['tv_err_save_access_permissions'] = 'テンプレート変数のアクセス権を設定中にエラーが発生しました。';
$_lang['tv_err_save'] = 'テンプレート変数の保存中にエラーが発生しました。';
$_lang['tv_inuse'] = '以下のドキュメントでこのテンプレート変数を使用しています。削除してよいですか？';
$_lang['tv_input_options'] = '入力オプション';
$_lang['tv_input_options_msg'] = '<p>投稿画面上の入力フィールドとしてのテンプレート変数の設定です。テキストエリアやラジオボタンなど、さまざまなフォームを利用できます。</p>';
$_lang['tv_lock'] = 'ロックする';
$_lang['tv_lock_msg'] = 'このテンプレート変数を編集するためにはロックの解除が必要です。';
$_lang['tv_management_msg'] = 'ドキュメントに追加されたカスタムコンテントフィールド（テンプレート変数）を管理します。';
$_lang['tv_msg'] = 'ここでテンプレート変数を追加・編集します。テンプレート変数を利用するためには任意のテンプレートに関連付ける必要がありますのでご注意ください。';
$_lang['tv_name'] = '変数名';
$_lang['tv_new'] = '新しいテンプレート変数';
$_lang['tv_novars'] = 'テンプレート変数が見つかりませんでした';
$_lang['tv_output_options'] = '出力オプション';
$_lang['tv_output_options_msg'] = '<p>ページ上での出力に関する設定。テンプレート変数として入力された値は、ここで設定したフィルターによる整形を通じて出力されます。「日付」や「画像」など、入力された値の形式に依存するものもありますのでご注意ください。そのまま出力する場合は「デフォルト」を選択してください。</p>';
$_lang['tv_properties'] = 'デフォルトのプロパティ';
$_lang['tv_rank'] = 'ソート順';
$_lang['tv_reset_params'] = 'パラメーターのリセット';
$_lang['tv_sources.intro_msg'] = 'Here you can assign the Media Sources that are to be used for this TV in each specified Context. Double-click on the Source name in the grid to change it.';
$_lang['tv_tmpl_access'] = 'テンプレートの割当';
$_lang['tv_tmpl_access_msg'] = 'このテンプレート変数へのアクセスを許可するテンプレートを選択して下さい。';
$_lang['tv_widget'] = 'ウィジェット';
$_lang['tv_widget_prop'] = 'ウィジェットのプロパティ';
$_lang['tvd_err_remove'] = 'ドキュメントからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvdg_err_remove'] = 'ドキュメントグループからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvdg_err_save'] = 'ドキュメントグループにテンプレート変数を設定中にエラーが発生しました。';
$_lang['tvs'] = 'テンプレート変数';
$_lang['tvt_err_nf'] = 'テンプレート変数は、そのテンプレートに対するアクセス権がありません。';
$_lang['tvt_err_remove'] = 'テンプレートからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvt_err_save'] = 'テンプレートにテンプレート変数を紐付け中にエラーが発生しました。';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/tv.inc.php <==
<?php
/**
 * TV English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['has_access'] = 'アクセスしますか？';
$_lang['rank'] = 'ランク';
$_lang['rendering_options'] = 'レンダリングオプション';
$_lang['tv'] = 'テンプレート変数';
$_lang['tv_access_msg'] = 'このテンプレート変数が所属するリソースグループを選択してください。選択したグループへのアクセス権を持つユーザのみがこのテンプレート変数を修正することができます。<br />もしグループが選ばれていなければ、管理画面へのアクセス権を持つ全てのユーザがテンプレート変数を修正することができます。';
$_lang['tv_binding_msg'] = 'このフィールドはデータソースバインディング（@コマンド）をサポートしています。';
$_lang['tv_caption'] = 'キャプション（見出し）';
$_lang['tv_change_template_msg'] = 'このテンプレートを変更するとこのページのテンプレート変数を再読み込みします。保存されていない変更は失われます。<br />本当にテンプレートを変更しますか？';
$_lang['tv_desc_caption'] = 'リソース編集時、テンプレート変数の横に見出しとして表示されるテキスト。';
$_lang['tv_desc_category'] = 'このテンプレート変数が属するカテゴリー。';
$_lang['tv_desc_description'] = 'このテンプレート変数の簡単な説明。';
$_lang['tv_desc_name'] = 'テンプレート変数の名前。テンプレート変数は[[*テンプレート変数名]]という書式で利用できるようになります。';
$_lang['tv_description'] = '説明';
$_lang['tv_err_delete'] = 'テンプレート変数の削除中にエラーが発生しました。';
$_lang['tv_err_duplicate'] = 'テンプレート変数の複製中にエラーが発生しました。';
$_lang['tv_err_duplicate_templates'] = 'テンプレート変数のテンプレートを複製中にエラーが発生しました。';
$_lang['tv_err_duplicate_documents'] = 'テンプレート変数のドキュメントを複製中にエラーが発生しました。';
$_lang['tv_err_duplicate_documentgroups'] = 'テンプレート変数のドキュメントグループを複製中にエラーが発生しました。';
$_lang['tv_err_exists_name'] = '[[+name]]という名前のテンプレート変数がすでに存在します。';
$_lang['tv_err_invalid_name'] = 'テンプレート変数名に無効な文字列が使用されています。';
$_lang['tv_err_locked'] = 'テンプレート変数がロックされました。';
$_lang['tv_err_nf'] = 'テンプレート変数が見つかりませんでした。';
$_lang['tv_err_nfs'] = 'キー「[[+id]]」に関するテンプレート変数は見つかりません。';
$_lang['tv_err_ns'] = 'テンプレート変数が指定されていません。';
$_lang['tv_err_reserved_name'] = 'テンプレート変数にはリソースフィールドと同じ名前を設定することはできません。';
$_lang['tv_err_save_access_permissions'] = 'テンプレート変数のアクセス権を設定中にエラーが発生しました。';
$_lang['tv_err_save'] = 'テンプレート変数の保存中にエラーが発生しました。';
$_lang['tv_inuse'] = '以下のドキュメントでこのテンプレート変数を使用しています。削除してよいですか？';
$_lang['tv_input_options'] = '入力オプション';
$_lang['tv_input_options_msg'] = '<p>投稿画面上の入力フィールドとしてのテンプレート変数の設定です。テキストエリアやラジオボタンなど、さまざまなフォームを利用できます。</p>';
$_lang['tv_lock'] = 'ロックする';
$_lang['tv_lock_msg'] = 'このテンプレート変数を編集するためにはロックの解除が必要です。';
$_lang['tv_management_msg'] = 'ドキュメントに追加されたカスタムコンテントフィールド（テンプレート変数）を管理します。';
$_lang['tv_msg'] = 'ここでテンプレート変数を追加・編集します。<br />テンプレート変数を利用するには、任意のテンプレートに関連付ける必要があるので注意してください。';
$_lang['tv_name'] = '変数名';
$_lang['tv_new'] = '新しいテンプレート変数';
$_lang['tv_novars'] = 'テンプレート変数が見つかりませんでした。';
$_lang['tv_output_options'] = '出力オプション';
$_lang['tv_output_options_msg'] = '<p>ページ上での出力に関する設定。テンプレート変数として入力された値は、ここで設定したフィルターによる整形を通じて出力されます。「日付」や「画像」など、入力された値の形式に依存するものもありますのでご注意ください。そのまま出力する場合は「デフォルト」を選択してください。</p>';
$_lang['tv_properties'] = 'デフォルトのプロパティ';
$_lang['tv_rank'] = 'ソート順';
$_lang['tv_reset_params'] = 'パラメーターのリセット';
$_lang['tv_sources.intro_msg'] = '各コンテキストごとに、このテンプレート変数で使用するメディアソースを指定できます。<br />編集するには、表の「ソース」セルをダブルクリックしてください。';
$_lang['tv_tmpl_access'] = 'テンプレートの割当';
$_lang['tv_tmpl_access_msg'] = 'このテンプレート変数へのアクセスを許可するテンプレートを選択してください。';
$_lang['tv_widget'] = 'ウィジェット';
$_lang['tv_widget_prop'] = 'ウィジェットのプロパティ';
$_lang['tvd_err_remove'] = 'ドキュメントからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvdg_err_remove'] = 'ドキュメントグループからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvdg_err_save'] = 'ドキュメントグループにテンプレート変数を設定中にエラーが発生しました。';
$_lang['tvs'] = 'テンプレート変数';
$_lang['tvt_err_nf'] = 'テンプレート変数は、そのテンプレートに対するアクセス権がありません。';
$_lang['tvt_err_remove'] = 'テンプレートからテンプレート変数を削除中にエラーが発生しました。';
$_lang['tvt_err_save'] = 'テンプレートにテンプレート変数を紐付け中にエラーが発生しました。';
